Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(45)

Unified Diff: content/browser/frame_host/render_frame_host_impl.h

Issue 2484633004: Change Lo-Fi bool to bitmask to support multiple Previews types (Closed)
Patch Set: fix ContentResourceProviderTest Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/frame_host/navigator_impl.cc ('k') | content/browser/frame_host/render_frame_host_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/frame_host/render_frame_host_impl.h
diff --git a/content/browser/frame_host/render_frame_host_impl.h b/content/browser/frame_host/render_frame_host_impl.h
index a8e1bde48bfcda14807174abf43c96c30e7a7399..7da685dff5bddb6e269dc04324446629e709d36b 100644
--- a/content/browser/frame_host/render_frame_host_impl.h
+++ b/content/browser/frame_host/render_frame_host_impl.h
@@ -38,6 +38,7 @@
#include "content/common/navigation_params.h"
#include "content/public/browser/render_frame_host.h"
#include "content/public/common/javascript_message_type.h"
+#include "content/public/common/previews_state.h"
#include "media/mojo/interfaces/interface_factory.mojom.h"
#include "net/http/http_response_headers.h"
#include "services/service_manager/public/cpp/interface_factory.h"
@@ -594,10 +595,11 @@ class CONTENT_EXPORT RenderFrameHostImpl
void ClearFocusedElement();
- // PlzNavigate: returns the LoFi state of the last successful navigation that
- // made a network request.
- LoFiState last_navigation_lofi_state() const {
- return last_navigation_lofi_state_;
+ // PlzNavigate: returns the PreviewsState of the last successful navigation
+ // that made a network request. The PreviewsState is a bitmask of potentially
+ // several Previews optimizations.
+ PreviewsState last_navigation_previews_state() const {
+ return last_navigation_previews_state_;
}
bool has_focused_editable_element() const {
@@ -1093,10 +1095,10 @@ class CONTENT_EXPORT RenderFrameHostImpl
// If true, then the RenderFrame has selected text.
bool has_selection_;
// PlzNavigate: The LoFi state of the last navigation. This is used during
// history navigation of subframes to ensure that subframes navigate with the
- // same LoFi status as the top-level frame.
- LoFiState last_navigation_lofi_state_;
+ // same Previews status as the top-level frame.
+ PreviewsState last_navigation_previews_state_;
mojo::Binding<mojom::FrameHost> frame_host_binding_;
mojom::FramePtr frame_;
« no previous file with comments | « content/browser/frame_host/navigator_impl.cc ('k') | content/browser/frame_host/render_frame_host_impl.cc » ('j') | no next file with comments »
@@ -1093,10 +1095,10 @@ class CONTENT_EXPORT RenderFrameHostImpl
// If true, then the RenderFrame has selected text.
bool has_selection_;
- // PlzNavigate: The LoFi state of the last navigation. This is used during
+ // PlzNavigate: The Previews state of the last navigation. This is used during
// history navigation of subframes to ensure that subframes navigate with the

Powered by Google App Engine
This is Rietveld 408576698